@@ -24,6 +24,7 @@ from .Image import Image
 from .InputWrapper import InputWrapper
 from .JsonInput import JsonInput
 from .Loader import Loader
+from .LoadingOverlay import LoadingOverlay
 from .MantineProvider import MantineProvider
 from .Modal import Modal
 from .MultiSelect import MultiSelect
@@ -82,6 +83,7 @@ __all__ = [
     "InputWrapper",
     "JsonInput",
     "Loader",
+    "LoadingOverlay",
     "MantineProvider",
     "Modal",
     "MultiSelect",
